Credits
=======

"snappass" is originally written and by Owen Coutts and Ryan Park.

It is currently maintained by Nicholas Charriere and Yongwen Xu from Pinterest.

Thanks a lot for the contributions of:

* Owen Coutts
* Ryan Park
* Yongwen Xu
* Nicholas Charriere
* Samuel Dion-Girardeau
* James W Thorne
* Brandon Davis
* Joseph Boiteau
* Carlos Moreno
* Donny Winston
* James Barclay
* Thomas Decaux
